package adminkindboxreqhandler

import (
	"net/http"
	"strconv"

	param "git.gocasts.ir/ebhomengo/niki/param/admin/kind_box_req"
	errmsg "git.gocasts.ir/ebhomengo/niki/pkg/err_msg"
	httpmsg "git.gocasts.ir/ebhomengo/niki/pkg/http_msg"
	echo "github.com/labstack/echo/v4"
)

// AssignSenderAgent godoc
// @Summary      admin AssignSenderAgent kindboxreq
// @Tags         kindboxreq
// @Accept       json
// @Produce      json
// @Param id path int true "Id"
// @Param Request body param.AssignSenderRequest true "admin AssignSenderAgent kindboxreq"
// @Success      200  {object}   param.DeliverKindBoxReqResponse
// @Failure      400  {string}  "Bad request"
// @Router      /admin/kindboxreqs/assign-sender-agent/{id} [patch]
// @Security AuthBearerAdmin
func (h Handler) AssignSenderAgent(c echo.Context) error {
	var req param.AssignSenderRequest

	if bErr := c.Bind(&req); bErr != nil {
		return echo.NewHTTPError(http.StatusBadRequest)
	}

	id, cErr := strconv.ParseUint(c.Param("id"), 10, 64)

	if cErr != nil {
		return c.JSON(http.StatusBadRequest, errmsg.ErrorMsgInvalidInput)
	}

	req.KindBoxReqID = uint(id)

	if fieldErrors, err := h.adminKindBoxReqVld.ValidateAssignSenderAgent(req); err != nil {
		msg, code := httpmsg.Error(err)

		return c.JSON(code, echo.Map{
			"message": msg,
			"errors":  fieldErrors,
		})
	}

	resp, sErr := h.adminKindBoxReqSvc.AssignSenderAgent(c.Request().Context(), req)

	if sErr != nil {
		msg, code := httpmsg.Error(sErr)

		return echo.NewHTTPError(code, msg)
	}

	return c.JSON(http.StatusOK, resp)
}
