package benefactorkindboxreqhandler

import (
	"fmt"
	"net/http"

	param "git.gocasts.ir/ebhomengo/niki/param/benefactor/kind_box_req"
	"git.gocasts.ir/ebhomengo/niki/pkg/claim"
	errmsg "git.gocasts.ir/ebhomengo/niki/pkg/err_msg"
	httpmsg "git.gocasts.ir/ebhomengo/niki/pkg/http_msg"
	echo "github.com/labstack/echo/v4"
)

// Add godoc
// @Summary      benefactor Add kindboxreq
// @Tags         kindboxreq
// @Accept       json
// @Produce      json
// @Param        Request body   param.KindBoxReqAddRequest true "benefactor Add kindboxreq"
// @Success      200  {object}  param.KindBoxReqAddResponse
// @Failure      400  {string}  "Bad request"
// @Router      /benefactor/kindboxreqs/ [post]
// @Security AuthBearerBenefactor
func (h Handler) Add(c echo.Context) error {
	req := param.KindBoxReqAddRequest{}
	if err := c.Bind(&req); err != nil {
		fmt.Println("err", err, req)

		return c.JSON(http.StatusBadRequest, echo.Map{
			"message": errmsg.ErrBadRequest,
		})
		// TODO: return echo.NewHTTPError(http.StatusBadRequest, errmsg.ErrBadRequest) ؟؟؟
	}
	claims := claim.GetClaimsFromEchoContext(c)
	req.BenefactorID = claims.UserID

	result := h.benefactorKindBoxReqVld.ValidateAddRequest(req)
	if result != nil {
		msg, code := httpmsg.Error(result.Err)

		return c.JSON(code, echo.Map{
			"message": msg,
			"errors":  result.Fields,
		})
	}
	resp, sErr := h.benefactorKindBoxReqSvc.Add(c.Request().Context(), req)
	if sErr != nil {
		msg, code := httpmsg.Error(sErr)

		return echo.NewHTTPError(code, msg)
	}

	return c.JSON(http.StatusCreated, resp)
}
